@@ -42,9 +42,10 @@ prhead_task()
 }
 
 addr_t
-print_task(addr, full)
+print_task(addr, full, sw)
 	addr_t addr;
 	int full;
+	int sw;
 {
 	struct task_struct ts;
 	char c;
