@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include "def.h"
@@ -55,16 +55,42 @@ print_files_struct(addr)
 }
 
 void
-prhead_task()
+prhead_task(sw)
+	int sw;
 {
+	const char *p;
+	switch (sw) {
+	default:
+		p = "MM";	break;
+	case 1:
+		p = "TTY";	break;
+	case 2:
+		p = "FS";	break;
+	case 3:
+		p = "USER";	break;
+#ifdef _task_struct_has_signal
+	case 4:
+		p = "SIGNAL";	break;
+#else
+#ifdef _task_struct_has_sig
+	case 4:
+		p = "SIG";	break;
+#endif
+#endif /*_task_struct_has_signal*/
+#ifdef _task_struct_has_namespace
+	case 5:
+		p = "NAMESPAC";	break;
+#endif /*_task_struct_has_namespace*/
+	}
 	mprintf(SPTR" S   PID   SID   UID  EUID "SPTR" NAME             FLAGS\n",
-		"ADDR", "MM");
+		"ADDR", p);
 }
 
 addr_t
-print_task(addr, full)
+print_task(addr, full, sw)
 	addr_t addr;
 	int full;
+	int sw;
 {
 	struct task_struct ts;
 	char c;
@@ -81,10 +107,35 @@ print_task(addr, full)
 #ifdef TASK_SWAPPING
 	case TASK_SWAPPING:		c = 'S';	break;
 #endif /*TASK_SWAPPING*/
+#ifdef TASK_DEAD
+	case TASK_DEAD:			c = 'D';	break;
+#endif /*TASK_DEAD*/
 	default:			c = '?';	break;
 	}
-	mprintf("%c %5d %5d %5d %5d", c, ts.pid, ts.session, ts.uid, ts.euid);
-	mprintf(" " FPTR, ts.mm);
+	mprintf("%c %5d %5d %5d %5d ", c, ts.pid, ts.session, ts.uid, ts.euid);
+	switch (sw) {
+	default:
+		mprintf(FPTR, ts.mm);	break;
+	case 1:
+		mprintf(FPTR, ts.tty);	break;
+	case 2:
+		mprintf(FPTR, ts.fs);	break;
+	case 3:
+		mprintf(FPTR, ts.user);	break;
+#ifdef _task_struct_has_signal
+	case 4:
+		mprintf(FPTR, ts.signal);	break;
+#else
+#ifdef _task_struct_has_sig
+	case 4:
+		mprintf(FPTR, ts.sig);	break;
+#endif
+#endif /*_task_struct_has_signal*/
+#ifdef _task_struct_has_namespace
+	case 5:
+		mprintf(FPTR, ts.namespace);	break;
+#endif /*_task_struct_has_namespace*/
+	}
 	mprintf(" %-16s", ts.comm);
 	mprintbit(tsflags, ts.flags);
 	mprintf("\n");
@@ -97,9 +148,17 @@ print_task(addr, full)
 	mprintf("\n");
 	mprintf("\tfs:" FPTR "\n", ts.fs);
 	mprintf("\texec_domain:" FPTR "\n", ts.exec_domain);
+#ifdef _task_struct_has_p_pptr
 	mprintf("\tpptr:" FPTR "\n", ts.p_pptr);
+#endif /*_task_struct_has_p_pptr*/
 	mprintf("\tuser:%lx  thread:%lx\n", ts.user, &((struct task_struct *)addr)->thread);
-	mprintf("\tsig:" FPTR "  blocked:%08lx %08lx\n", ts.sig, ts.blocked.sig[0], ts.blocked.sig[1]);
+#ifdef _task_struct_has_signal
+	mprintf("\tsignal:" FPTR "\n", ts.signal);
+#endif /*_task_struct_has_sigal*/
+#ifdef _task_struct_has_sig
+	mprintf("\tsig:" FPTR "\n", ts.sig);
+#endif /*_task_struct_has_sig*/
+	mprintf("\tblocked:%08lx %08lx\n", ts.blocked.sig[0], ts.blocked.sig[1]);
 	mprintf("\ttty_struct:" FPTR "\n", ts.tty);
 
 #if defined(ARCH_i386)
@@ -115,7 +174,16 @@ print_task(addr, full)
 	mprintf("\n");
 
 out:
+#ifdef _task_struct_has_next_task
 	return (addr_t)ts.next_task;
+#else /*_task_struct_has_next_task*/
+#ifdef _task_struct_has_tasks
+	return (addr_t)ts.tasks.next - OFFSET(struct task_struct, tasks);
+#else /*_task_struct_has_tasks*/
+#error "task_struct has no next chain"
+	return 0;
+#endif /*_task_struct_has_tasks*/
+#endif /*_task_struct_has_next_task*/
 }
 
 int
@@ -209,7 +277,16 @@ search_task(addr)
 				tsk.pid, addr - taddr);
 			return 1;
 		}
+#ifdef _task_struct_has_next_task
 		taddr = (addr_t)tsk.next_task;
+#else
+#ifdef _task_struct_has_tasks
+		taddr = (addr_t)tsk.tasks.next - OFFSET(struct task_struct, tasks);
+#else
+#error "task_struct has no next chain"
+		taddr = 0;
+#endif
+#endif /*_task_struct_has_next_task*/
 	} while (taddr != init_task_addr);
 
 	return 0;	/* not found */
