@@ -49,6 +49,10 @@ print_slab(addr, num)
 			mprintf(" %x", ix);
 			if (buf[ix] == BUFCTL_END)
 				break;
+			else if (buf[ix] == ix) {
+				mprintf("...?\n");
+				return 0;
+			}
 			ix = buf[ix];
 		}
 		mprintf("\n");
