@@ -139,7 +139,7 @@ zone()
 		GETADDR(pgdat_list);
 		memread(pgdat_list_addr, sizeof(zaddr), &zaddr, "pgdat_list");
 		prhead_zone();
-		for (i = 0; addr = get_zone_from_pglist_data(zaddr, i); i++) {
+		for (i = 0; (addr = get_zone_from_pglist_data(zaddr, i)); i++) {
 			print_zone(addr, 0);
 		}
 		return addr;
