@@ -31,6 +31,7 @@ extern const commandtable_t
 	command_usb_driver,
 	command_vg,
 	command_vm_area_struct,
+	command_vm_struct,
 	command_zone;
 
 const commandtable_t *commandtable_vers[] = {
@@ -74,6 +75,7 @@ const commandtable_t *commandtable_vers[] = {
 	&command_vg,
 #endif
 	&command_vm_area_struct,
+	&command_vm_struct,
 	&command_zone,
 };
 const int ncmdtable_vers = LENGTHOF(commandtable_vers);
