@@ -17,7 +17,7 @@ PRIVATE addr_t
 vfsmount()
 {
 	int i, c;
-	addr_t addr;
+	addr_t addr = 0;
 	extern void prhead_vfsmount();
 
 	while ((c = getopt(argcnt, args, "")) != EOF) {
