@@ -8,50 +8,9 @@
 #include <linux/blkdev.h>
 #include "printdev.h"
 
-addr_t print_blk_dev_struct();
 addr_t print_request_queue();
 addr_t print_request();
 
-void
-prhead_blk_dev_struct()
-{
-	mprintf(SPTR " DEV " SPTR " " SPTR "\n", "ADDR", "QUEUE", "DATA");
-}
-
-addr_t
-print_blk_dev_struct(addr, n, full)
-	addr_t addr;
-	int n;
-	int full;
-{
-	struct blk_dev_struct bd;
-
-	if (n >= 0) {
-		addr += sizeof(bd) * n;
-	}
-	memread(addr, sizeof(bd), &bd, "blk_dev_struct");
-	if (bd.queue == NULL && bd.data == NULL) {
-		int i;
-		char *p;
-		for (i = 0, p = (char *)&bd; i < sizeof(&bd) && *p == 0; i++, p++)
-			;
-		if (i == sizeof(&bd))
-			return -1;
-	}
-
-	mprintf(FPTR " ", addr);
-	if (n >= 0) {
-		mprintf("%3d ", n);
-	} else {
-		mprintf("  - ");
-	}
-	mprintf(FPTR " " FPTR "\n", bd.queue, bd.data);
-	if (full) {
-		print_request_queue(addr, 1);
-	}
-	return 0;
-}
-
 addr_t
 print_request_queue(addr, full)
 	addr_t addr;
@@ -125,7 +84,6 @@ print_request(addr)
 
 	memread(addr, sizeof(req), &req, "request");
 	mprintf(FPTR " ", addr);
-	print_kdev_t(req.rq_dev);
 	mprintf(" %02x %8lx %5lx " FPTR " " FPTR " " FPTR "\n", req.cmd[0], req.sector, req.nr_sectors, req.buffer, req.bio, req.q);
 
 	return (addr_t) req.queuelist.next;
