@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include "def.h"
@@ -34,21 +34,26 @@ prhead_dentry()
 }
 
 addr_t
-print_dentry(addr, dhash, subdir, parent)
+print_dentry(addr, sw, subdir, parent)
 	addr_t addr;
-	int dhash, subdir, parent;
+	int sw, subdir, parent;
 {
 	struct dentry de;
 	addr_t child, next;
 
-	if (dhash) {
-		addr -= (addr_t)&((struct dentry *)NULL)->d_hash;
+	switch (sw) {
+	case 1:	/* hash */
+		addr -= OFFSET(struct dentry, d_hash);
+		break;
+	case 2:	/* lru */
+		addr -= OFFSET(struct dentry, d_lru);
+		break;
 	}
 	memread(addr, sizeof(de), &de, "dentry");
 
 	if (subdir) {
 		for (next = (addr_t)de.d_subdirs.next; next != (addr_t)&((struct dentry *)addr)->d_subdirs; next = (addr_t)de.d_child.next) {
-			child = next - (addr_t)&((struct dentry *)NULL)->d_child;
+			child = next - OFFSET(struct dentry, d_child);
 			memread(child, sizeof(de), &de, "dentry");
 			(void)print_dentry(child, 0, 0, 0);
 		}
@@ -87,7 +92,10 @@ print_dentry(addr, dhash, subdir, parent)
 		return 0;
 	}
 
-	return (addr_t)de.d_hash.next;
+	if (sw == 2)
+		return (addr_t)de.d_lru.next;
+	else
+		return (addr_t)de.d_hash.next;
 }
 
 void
@@ -184,7 +192,7 @@ print_inode(addr, full)
 	mprintf(" %5d %10Lx", inode.i_uid, inode.i_size);
 	mprintf(" " FPTR, inode.i_mapping);
 	mprintf(" %c%c%c\n",
-		(inode.i_hash.next         !=&((struct inode *)addr)->i_hash         )? 'H': '-',
+		(inode.i_hash.pprev        !=NULL)? 'H': '-',
 		(inode.i_list.next         !=&((struct inode *)addr)->i_list         )? 'L': '-',
 		(inode.i_dentry.next       !=&((struct inode *)addr)->i_dentry       )? 'D': '-');
 
@@ -386,28 +394,6 @@ print_address_space(addr, plist)
 	}
 }
 
-void
-prhead_char_device()
-{
-	mprintf(SPTR" COUNT   DEV   OPEN SEM C SLP\n", "ADDR");
-}
-
-addr_t
-print_char_device(addr)
-	addr_t addr;
-{
-	struct char_device cd;
-
-	memread(addr, sizeof(cd), &cd, "char_device");
-	mprintf(FPTR " ", addr);
-
-	mprintf("%5x ", ATOMIC_READ(cd.count));
-	print_dev_t(cd.dev);
-	mprintf(" %4x ", ATOMIC_READ(cd.openers));
-	mprintf("%5d %3d\n", ATOMIC_READ(cd.sem.count), cd.sem.sleepers);
-	return (addr_t)cd.hash.next;
-}
-
 void
 prhead_block_device()
 {
