@@ -21,6 +21,13 @@ print_namespace(addr)
 {
 	struct namespace ns;
 
+	if (addr == 0) {
+		struct task_struct ts;
+
+		memread(init_task_addr, sizeof(struct task_struct), &ts, "task_struct");
+		addr = ts.namespace;
+	}
+
 	memread(addr, sizeof(struct namespace), &ns, "namespace");
 	mprintf(FPTR " %3x " FPTR " ", addr, ATOMIC_READ(ns.count), ns.root);
 	if (ns.list.next && (addr_t)ns.list.next != addr + OFFSET(struct namespace, list)) {
