@@ -65,6 +65,7 @@ struct sizetbl sizetbl[] = {
 	{ "signal_struct",	sizeof(struct signal_struct) },
 	{ "sigpending",		sizeof(struct sigpending) },
 	{ "sigset_t",		sizeof(sigset_t) },
+	{ "size_t",		sizeof(size_t) },
 	{ "slab",		sizeof(struct slab) },
 	{ "socket",		sizeof(struct socket) },
 	{ "spinlock_t",		sizeof(spinlock_t) },
@@ -76,6 +77,7 @@ struct sizetbl sizetbl[] = {
 	{ "umode_t",		sizeof(umode_t) },
 	{ "vfsmount",		sizeof(struct vfsmount) },
 	{ "vm_area_struct",	sizeof(struct vm_area_struct) },
+	{ "vm_struct",		sizeof(struct vm_struct) },
 	{ "wait_queue_head_t",	sizeof(wait_queue_head_t) },
 	{ "zone",		sizeof(struct zone) },
 };
