@@ -190,7 +190,7 @@ print_usb_bus(addr, list_offset)
 void
 prhead_usb_device()
 {
-	mprintf(SPTR" DEV S "SPTR" P CNT -- -- "SPTR" "SPTR" "SPTR" "SPTR"\n",
+	mprintf(SPTR" DEV S "SPTR" P -- -- "SPTR" "SPTR" "SPTR" "SPTR"\n",
 		"ADDR", "DEVICE", "PARENT", "BUS", "CONFIG", "HCPRIV");
 }
 
@@ -210,7 +210,6 @@ print_usb_device(addr)
 			(ud.speed==USB_SPEED_FULL? 'F':
 			(ud.speed==USB_SPEED_HIGH? 'H': '?'))));
 	mprintf(FPTR " %x ", ud.tt, ud.ttport);
-	mprintf("%3x ", ATOMIC_READ(ud.refcnt));
 	mprintf("%x%x %x%x ", ud.toggle[0], ud.toggle[1], ud.halted[0], ud.halted[1]);
 	mprintf(FPTR " " FPTR " " FPTR " " FPTR " ", ud.parent, ud.bus, ud.config, ud.hcpriv);
 #if 0
