@@ -16,18 +16,20 @@ PRIVATE addr_t
 namespace()
 {
 	int c;
+	addr_t addr = 0;
 
 	while ((c = getopt(argcnt, args, "")) != EOF) {
 		THROW(usage);
 	}
 
+	prhead_namespace();
 	if (argcnt == optind) {
-		THROW(usage);
+		addr = print_namespace(0);
+	} else {
+		while (args[optind]) {
+			addr = print_namespace(getaddr(args[optind]));
+			optind++;
+		}
 	}
-	while (args[optind]) {
-		prhead_namespace();
-		print_namespace(getaddr(args[optind]));
-		optind++;
-	}
-	return 0;
+	return addr;
 }
