@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -12,7 +12,7 @@ const commandtable_t command_slab =
 	{"slab", slab, "address", "print slab table"};
 extern void prhead_slab();
 
-addr_t cache_cache_addr;
+addr_t cache_chain_addr;
 addr_t print_kmem_cache(), print_slab();
 
 PRIVATE addr_t
@@ -33,19 +33,19 @@ kmem_cache()
 		}
 	}
 
-	GETADDR(cache_cache);
+	GETADDR(cache_chain);
 
 	if (argcnt > optind) {
 		for (i = optind; i < argcnt; i++) {
 			addr = getaddr(args[i]);
-			addr = print_kmem_cache(addr, sflag, 1);
+			addr = print_kmem_cache(addr, sflag, 1, 0);
 		}
 	} else {
 		if (!sflag) prhead_kmem_cache();
-		addr = print_kmem_cache(cache_cache_addr, sflag, 0);
-		while (addr && addr != cache_cache_addr) {
+		memread(cache_chain_addr, sizeof(addr), &addr, "cache_chain");
+		while (addr && addr != cache_chain_addr) {
 			if (sflag) prhead_kmem_cache();
-			addr = print_kmem_cache(addr, sflag, 0);
+			addr = print_kmem_cache(addr, sflag, 0, 1);
 		}
 	}
 
