@@ -4,7 +4,6 @@ extern const commandtable_t
 	command_address_space,
 	command_block_device,
 	command_buffer_head,
-	command_char_device,
 	command_ext2_inode,
 	command_fib_table,
 	command_file,
@@ -26,13 +25,13 @@ extern const commandtable_t
 	command_usb_device,
 	command_usb_driver,
 	command_vm_area_struct,
+	command_vm_struct,
 	command_zone;
 
 const commandtable_t *commandtable_vers[] = {
 	&command_address_space,
 	&command_block_device,
 	&command_buffer_head,
-	&command_char_device,
 	&command_ext2_inode,
 	&command_fib_table,
 	&command_file,
@@ -56,6 +55,7 @@ const commandtable_t *commandtable_vers[] = {
 	&command_usb_driver,
 #endif
 	&command_vm_area_struct,
+	&command_vm_struct,
 	&command_zone,
 };
 const int ncmdtable_vers = LENGTHOF(commandtable_vers);
@@ -63,9 +63,9 @@ const int ncmdtable_vers = LENGTHOF(commandtable_vers);
 void
 vers_init()
 {
-	extern addr_t cache_cache_addr;
+	extern addr_t cache_chain_addr;
 	extern addr_t init_task_addr;
 
-	cache_cache_addr = searchaddr_bysym("cache_cache");
+	cache_chain_addr = searchaddr_bysym("cache_chain");
 	init_task_addr = searchaddr_bysym("init_task");
 }
