@@ -4,6 +4,7 @@
 
 #include <unistd.h>
 #include "crash.h"
+#include "mpercpu.h"
 
 #include <linux/timer.h>
 
@@ -17,17 +18,15 @@
 #define TVR_MASK (TVR_SIZE - 1)
 
 typedef struct tvec_s {
-	int index;
 	struct list_head vec[TVN_SIZE];
 } tvec_t;
 
 typedef struct tvec_root_s {
-	int index;
 	struct list_head vec[TVR_SIZE];
 } tvec_root_t;
 
 struct tvec_t_base_s {
-	struct { int dummy; } lock;
+	spinlock_t lock;
 	unsigned long timer_jiffies;
 	void *running_timer;
 	tvec_root_t tv1;
@@ -43,7 +42,7 @@ PRIVATE addr_t timer_vec();
 const commandtable_t command_timer_vec =
 	{"timer_vec", timer_vec, "", "print timer_vec table (tv1-tv5)"};
 
-addr_t tvec_bases_addr;	/* per_cpu ... but not yet */
+IMPORT_PER_CPU(tvec_bases);
 addr_t jiffies_addr;
 
 void
@@ -53,9 +52,10 @@ prhead_timer_vec()
 }
 
 void
-print_timer_vec(tvn, addr)
+print_timer_vec(tvn, addr, index)
 	int tvn;
 	addr_t addr;
+	unsigned long index;
 {
 	int i;
 	struct tvec_root_s tv;
@@ -66,7 +66,7 @@ print_timer_vec(tvn, addr)
 	/* sizeof(timer_vec) < sizeof(timer_vec_root) */
 	memread(addr, sizeof(struct tvec_root_s), &tv, "timer_vec");
 
-	mprintf("\ntv%x  (%lx)  index: %d\n", tvn, addr, tv.index);
+	mprintf("\ntv%x  (%lx)  index: %ld\n", tvn, addr, index);
 	prhead_timer_vec();
 	for (i = 0; i < ((tvn == 1)? TVR_SIZE: TVN_SIZE); i++) {
 		for (vec = (addr_t)tv.vec[i].next; vec; vec = (addr_t)tl.entry.next) {
@@ -93,9 +93,15 @@ timer_vec()
 	int i, c;
 	char buf[32];
 	unsigned long jiffies;
+	int cpu = 0;
 
-	while ((c = getopt(argcnt, args, "")) != EOF) {
+	while ((c = getopt(argcnt, args, "n:")) != EOF) {
 		switch (c) {
+		case 'n':
+			cpu = (int)strtol(optarg, NULL, 0);
+			if (cpu < 0)
+				THROW(usage);
+			break;
 		default:
 			THROW(usage);
 		}
@@ -104,18 +110,24 @@ timer_vec()
 	if (optind != argcnt)
 		THROW(usage);
 
-	GETADDR(tvec_bases);
+	GETADDR(tvec_bases__per_cpu);
 	GETADDR(jiffies);
 	memread(jiffies_addr, sizeof(jiffies), &jiffies, "jiffies");
 	mprintf("jiffies = %lx\n", jiffies);
 
 	/*NR_CPUS*/
 	{
-		print_timer_vec(1, tvec_bases_addr + OFFSET(struct tvec_t_base_s, tv1));
-		print_timer_vec(2, tvec_bases_addr + OFFSET(struct tvec_t_base_s, tv2));
-		print_timer_vec(3, tvec_bases_addr + OFFSET(struct tvec_t_base_s, tv3));
-		print_timer_vec(4, tvec_bases_addr + OFFSET(struct tvec_t_base_s, tv4));
-		print_timer_vec(5, tvec_bases_addr + OFFSET(struct tvec_t_base_s, tv5));
+		unsigned long timerj;
+		memread(PER_CPU_ADDR(struct tvec_t_base_s, tvec_bases, cpu) + OFFSET(struct tvec_t_base_s, timer_jiffies), sizeof(timerj), &timerj, "timer_jiffies");
+		print_timer_vec(1, PER_CPU_ADDR(struct tvec_t_base_s, tvec_bases, cpu) + OFFSET(struct tvec_t_base_s, tv1), timerj & TVR_MASK);
+		timerj >>= TVR_BITS;
+		print_timer_vec(2, PER_CPU_ADDR(struct tvec_t_base_s, tvec_bases, cpu) + OFFSET(struct tvec_t_base_s, tv2), timerj & TVN_MASK);
+		timerj >>= TVN_BITS;
+		print_timer_vec(3, PER_CPU_ADDR(struct tvec_t_base_s, tvec_bases, cpu) + OFFSET(struct tvec_t_base_s, tv3), timerj & TVN_MASK);
+		timerj >>= TVN_BITS;
+		print_timer_vec(4, PER_CPU_ADDR(struct tvec_t_base_s, tvec_bases, cpu) + OFFSET(struct tvec_t_base_s, tv4), timerj & TVN_MASK);
+		timerj >>= TVN_BITS;
+		print_timer_vec(5, PER_CPU_ADDR(struct tvec_t_base_s, tvec_bases, cpu) + OFFSET(struct tvec_t_base_s, tv5), timerj & TVN_MASK);
 	}
 	return 0;
 }
