@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <string.h>
@@ -190,7 +190,7 @@ trace()
 		}
 		retad = *(unsigned int *)&stack[esp - stacktop];
 		if ((sym = searchsym_byaddr(retad)) == NULL ||
-		    sym->addr <= retad && sym->addr + 1 >= retad) {
+		    (sym->addr <= retad && sym->addr + 1 >= retad)) {
 			/* maybe stack analyze fail, do RECOVERY code */
 			/* save the pointers */
 			int esp_save = esp, retad_save = retad;
@@ -282,7 +282,7 @@ trace()
 					break;
 				mprintf("%x", *(int*)&stack[esp - stacktop + sizeof(int) + i]);
 			}
-		} else if (strcmp(sym->name, "system_call") == 0) {
+		} else /*if (strcmp(sym->name, "system_call") == 0)*/ {
 			for (i = 0; i < 4 * sizeof(int); i += sizeof(int)) {
 				if (i) mprintf(",");
 				if (!INTHESTACK(esp + sizeof(int) + i))
