@@ -71,7 +71,8 @@ extern void mprintf(const char *fmt, ...)
 extern void mprintbit(const struct bitname *, long);
 extern void mprint_str(const unsigned char *p, int maxlen);
 extern void pmode(int);
-extern int m_ntohl(int);
+extern unsigned int m_ntohl(unsigned int);
+extern unsigned short m_ntohs(unsigned short);
 extern int search_slab(addr_t addr);
 extern int search_task(addr_t addr);
 extern void vers_init(void);
