@@ -40,13 +40,27 @@ printxd(p, addr, size, mode)
 	static int initialized = 0;
 	int i;
 	int astmode = 0;
+	unsigned char membuf[16384+16];
+	int area;
 
 	if (! initialized) {
 		initialized = 1;
 		dumpinit();
 	}
 
+	area = p? size: 0;
+
 	for (i = 0; i <= size - 16; i += 16, p += 16, addr += 16) {
+		if (i >= area) {
+			memcpy(membuf, membuf + sizeof(membuf) - 16, 16);
+			area = size - i;
+			if (area > sizeof(membuf) - 16) {
+				area = sizeof(membuf) - 16;
+			}
+			memread(addr, area, membuf + 16, "kernel memory");
+			p = membuf + 16;
+			area += i;
+		}
 		if (i && memcmp(p, p - 16, 16) == 0) {
 			if (! astmode) {
 				mprintf("*\n");
@@ -99,22 +113,26 @@ printxd(p, addr, size, mode)
 		mprintf("\n");
 		return;
 	}
+	if (i >= area) {
+		memread(addr, size - i, membuf, "kernel memory");
+		p = membuf;
+	}
 	switch (mode) {
 	case BYBYTE: {
 	/*	 _+0+1+2+3 +4+5+6+7 +8+9+a+b +c+d+e+f  0123456789abcdef */
 #define	BUFORIG	"                                                      \n"
-		char	buf[sizeof(BUFORIG)];
+		char	line[sizeof(BUFORIG)];
 		int	m = 1, n;
 
-		strcpy(buf, BUFORIG);
+		strcpy(line, BUFORIG);
 		for (n = 0; i < size; i++, n++, p++) {
-			buf[m++] = int2h[*p / 16];
-			buf[m++] = int2h[*p % 16];
-			buf[38 + n] = chr2d[*p];
+			line[m++] = int2h[*p / 16];
+			line[m++] = int2h[*p % 16];
+			line[38 + n] = chr2d[*p];
 			if ((i % 4) == 3)
 				m++;
 		}
-		mprintf("%s", buf);
+		mprintf("%s", line);
 		}
 		break;
 	case BYHALFWORD: {
@@ -150,8 +168,7 @@ dump()
 	int c;
 	prmode_t mode = BYBYTE;
 	addr_t addr;
-	int size = 16, csize, off;
-	static char buf[65536];
+	int size = 16;
 
 	while ((c = getopt(argcnt, args, "1248hwd")) != EOF) {
 		switch (c) {
@@ -191,13 +208,6 @@ dump()
 	if (size & ((int)mode - 1)) {
 		THROW("invalid size");
 	}
-	for (off = 0; off < size; off += csize) {
-		csize = size;
-		if (csize > sizeof(buf)) {
-			csize = sizeof(buf);
-		}
-		memread(addr + off, csize, buf, "kernel memory");
-		printxd(buf, addr + off, csize, mode);
-	}
+	printxd(NULL, addr, size, mode);
 	return 0;
 }
