@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include <unistd.h>
@@ -40,7 +40,7 @@ module()
 		}
 	} else {
 #if LINUXVER>=25
-		addr_t modules_addr;
+		static addr_t modules_addr;
 		GETADDR(modules);
 		module_list_addr = modules_addr;
 #else
