@@ -344,6 +344,10 @@ searchsym_byaddr(addr)
 	} else if (min >= nsym - 1 && addr > symtable[min].addr) {
 		return NULL;	/* over */
 	}
+#if 1
+	if (strcmp(symtable[min].name, "_end") == 0 && symtable[min].addr != addr)
+		return NULL;
+#endif
 	cached = min;
 	if (symtable[min].addr == kmem_high && addr != kmem_high)
 		return NULL;	/* between static-linked and module address */
