@@ -10,6 +10,7 @@ extern const commandtable_t
 	command_alias,
 	command_date,
 	command_dentry,
+	command_dmesg,
 	command_dsymbol,
 	command_dump,
 	command_echo,
@@ -36,6 +37,7 @@ const commandtable_t *commandtable_base[] = {
 	&command_alias,
 	&command_date,
 	&command_dentry,
+	&command_dmesg,
 	&command_dsymbol,
 	&command_dump,
 	&command_echo,
