@@ -28,35 +28,39 @@ PRIVATE addr_t
 task()
 {
 	int i, c;
-	int full = 0;
+	int full = 0, sw = 0;
 	addr_t addr = 0;
 	extern void prhead_task();
 
-	while ((c = getopt(argcnt, args, "f")) != EOF) {
+	while ((c = getopt(argcnt, args, "fn:")) != EOF) {
 		switch (c) {
 		case 'f':
 			full = 1;
 			break;
+		case 'n':
+			sw = strtol(optarg, NULL, 0);
+			break;
 		default:
 			THROW(usage);
 		}
 	}
 
-	if (!full) prhead_task();
+	if (!full) prhead_task(sw);
 	if (argcnt > optind) {
 		for (i = optind; i < argcnt; i++) {
 			addr = getaddr(args[i]);
-			if (full) prhead_task();
-			addr = print_task(addr, full);
+			if (full) prhead_task(sw);
+			addr = print_task(addr, full, sw);
 		}
 	} else {
 		GETADDR(init_task);
 		addr = init_task_addr;
 		do {
-			if (full) prhead_task();
-			addr = print_task(addr, full);
+			if (full) prhead_task(sw);
+			addr = print_task(addr, full, sw);
 		} while (addr != init_task_addr);
 	}
+	if (!full) prhead_task(sw);
 	return addr;
 }
 
