@@ -1,11 +1,19 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include "def.h"
 
 #define __KERNEL__
 #include <xfs.h>
+#include <xfs_inum.h>
+#include <xfs_sb.h>
+#include <xfs_log.h>
+#include <xfs_trans.h>
+#include <xfs_dir.h>
+#include <xfs_dmapi.h>
+#include <xfs_mount.h>
+#include <xfs_log_priv.h>
 
 addr_t
 print_xlog(addr)
