@@ -1,11 +1,27 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include "def.h"
 
 #define __KERNEL__
 #include <xfs.h>
+#include <xfs_inum.h>
+#include <xfs_log.h>
+#include <xfs_trans.h>
+#include <xfs_sb.h>
+#include <xfs_dir.h>
+#include <xfs_dir2.h>
+#include <xfs_dmapi.h>
+#include <xfs_mount.h>
+#include <xfs_bmap_btree.h>
+#include <xfs_attr_sf.h>
+#include <xfs_dir_sf.h>
+#include <xfs_dir2_sf.h>
+#include <xfs_dinode.h>
+#include <xfs_inode.h>
+
+#include "flags_mount.h"
 
 #define	IFLAG	1
 #define	LFLAG	2
@@ -23,17 +39,22 @@ print_xfs_mount(addr, flag)
 {
 	xfs_mount_t m;
 	char name[32];
+#if 0
 	static const struct bitname mflags[] = {
 		{ XFS_MOUNT_WSYNC,		"wsync" },
 #ifdef XFS_MOUNT_INO64
 		{ XFS_MOUNT_INO64,		"ino64" },
 #endif
+#ifdef XFS_MOUNT_ROOTQCHECK
 		{ XFS_MOUNT_ROOTQCHECK,		"rootqcheck" },
+#endif
 		{ XFS_MOUNT_FS_SHUTDOWN,	"fs_shutdown" },
 		{ XFS_MOUNT_NOATIME,		"noatime" },
 		{ XFS_MOUNT_RETERR,		"reterr" },
 		{ XFS_MOUNT_NOALIGN,		"noalign" },
+#ifdef XFS_MOUNT_REGISTERED
 		{ XFS_MOUNT_REGISTERED,		"registered" },
+#endif
 		{ XFS_MOUNT_NORECOVERY,		"norecovery" },
 		{ XFS_MOUNT_SHARED,		"shared" },
 		{ XFS_MOUNT_DFLT_IOSIZE,	"dflt_iosize" },
@@ -49,9 +70,13 @@ print_xfs_mount(addr, flag)
 #endif
 #ifdef XFS_MOUNT_IRIXSGID
 		{ XFS_MOUNT_IRIXSGID,		"irixsgid" },
+#endif
+#ifdef XFS_MOUNT_NOLOGFLUSH
+		{ XFS_MOUNT_NOLOGFLUSH,		"nologflush" },
 #endif
 		{ 0,				NULL }
 	};
+#endif
 
 	mprintf("addr     " FPTR "\n", addr);
 	memread(addr, sizeof(m), &m, "xfs_mount_t");
@@ -78,10 +103,10 @@ print_xfs_mount(addr, flag)
 	mprintf("rbmip    " FPTR "\n", m.m_rbmip);
 	mprintf("rsumip   " FPTR "\n", m.m_rsumip);
 	mprintf("rootip   " FPTR "\n", m.m_rootip);
-#if 1
+#ifdef _xfs_mount_has_m_logdev_targp
 	/* new style */
 	mprintf("m_ddev_targp   " FPTR "\n", m.m_ddev_targp);
-	mprintf("m_logdev_targ  " FPTR "\n", m.m_logdev_targp);
+	mprintf("m_logdev_targp " FPTR "\n", m.m_logdev_targp);
 #else
 	/* old fashion */
 	mprintf("m_ddev_targ   " FPTR " " FPTR " %04x\n",
