@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include "def.h"
@@ -9,12 +9,16 @@
 #define _PAGE_BUF_INTERNAL_
 #include <linux/fs.h>
 #include <linux/page_buf.h>
-#else
+#else /*XFS_OLDDIR*/
 #ifdef HAVE_AVL
 #include <avl.h>
 #endif
+#include <linux/slab.h>	/* for old version */
 #include <page_buf.h>
+#ifdef HAVE_PB_INTERNAL
+#include <page_buf_internal.h>
 #endif
+#endif /*XFS_OLDDIR*/
 
 #include "flags_pagebuf.h"
 
@@ -57,14 +61,25 @@ print_pagebuf(addr, fflag)
 		mprintf("  strat:  " FPTR "\n", pb.pb_strat);
 		mprintf("  locked:    %x\n", pb.pb_locked);
 		mprintf("  fspriv  " FPTR "\n", pb.pb_fspriv);
-		mprintf("  iodonesema:\n");
-#if 1
-		/* new style */
+		mprintf("  fspriv2 " FPTR "\n", pb.pb_fspriv2);
+		mprintf("  fspriv3 " FPTR "\n", pb.pb_fspriv3);
+		mprintf("  sema:\n");
 		prhead_semaphore();
+#ifdef _page_buf_s_has_pb_sema
+		/* new style */
+		print_semaphore(addr + OFFSET(page_buf_t, pb_sema));
+#else
+		/* old fashion */
+		print_semaphore(addr + OFFSET(struct page_buf_private_s, pb_sema));
+#endif
+
+		mprintf("  iodonesema:\n");
+		prhead_semaphore();
+#ifdef _page_buf_s_has_pb_iodonesema
+		/* new style */
 		print_semaphore(addr + OFFSET(page_buf_t, pb_iodonesema));
 #else
 		/* old fashion */
-		prhead_semaphore();
 		print_semaphore(addr + OFFSET(struct page_buf_private_s, pb_iodonesema));
 		/*struct page_buf_private_s priv;*/
 		/*memread(addr, sizeof(priv), &priv, "page_buf_private_t");*/
