@@ -1,11 +1,13 @@
 /*
- * Copyright (C) 2000-2002 ASANO Masahiro
+ * Copyright (C) 2000-2003 ASANO Masahiro
  */
 
 #include "def.h"
 
 #define __KERNEL__
 #include <xfs.h>
+#include <xfs_log.h>
+#include <xfs_trans.h>
 
 void
 prhead_xfs_log_item()
@@ -45,7 +47,9 @@ print_xfs_log_item(addr)
 	case XFS_LI_BUF:	mprintf("BUF     ");	break;
 	case XFS_LI_DQUOT:	mprintf("DQUOT   ");	break;
 	case XFS_LI_QUOTAOFF:	mprintf("QUOTAOFF");	break;
+#ifdef XFS_LI_RPC
 	case XFS_LI_RPC:	mprintf("RPC     ");	break;
+#endif
 	}
 	mprintbit(liflags, li.li_flags);
 	mprintf("\n");
